%define product_family Amazon Linux
%define dist_tag amzn
%define dist_version 2

%define full_release_version %{dist_version}
%define upstream_rel 7.5
%define dist .%{dist_tag}%{dist_version}

%define cpe cpe:2.3:o:amazon:amazon_linux:%{dist_version}

Name:           system-release
Epoch:          1
Version:        %{dist_version}
Release:        4%{?dist}
Summary:        %{product_family} release files
Group:          System Environment/Base
License:        GPLv2
URL:            https://amazonlinux.com/
Provides:       centos-release = %{upstream_rel}
Provides:       redhat-release = %{upstream_rel}
Provides:       system-release(releasever) = %{dist_version}

# allow using the %%{_presetdir} macro
BuildRequires:  systemd

Source0:        GPL
# systemd preset files (via upstream)
Source1:        85-display-manager.preset
Source2:        90-default.preset
# yum repos
Source10:       amzn2-core.repo
# GPG keys
Source20:       RPM-GPG-KEY-amazon-linux-2
# cloud-init configuration
Source30:       10_aws_yumvars.cfg
# update-motd scripts
Source40:        30-banner
Source41:        70-available-updates

%description
%{product_family} release files


%prep


%build


%install
# create /etc
mkdir -p %{buildroot}/etc

# create /etc/system-release
echo "%{product_family} %{full_release_version}" > %{buildroot}/etc/system-release


# create /etc/os-release
cat << EOF >>%{buildroot}/etc/os-release
NAME="%{product_family}"
VERSION="%{dist_version}"
ID="%{dist_tag}"
ID_LIKE="centos rhel fedora"
VERSION_ID="%{dist_version}"
PRETTY_NAME="%{product_family} %{full_release_version}"
ANSI_COLOR="0;33"
CPE_NAME="%{cpe}"
HOME_URL="https://amazonlinux.com/"
EOF
# write cpe to /etc/system/release-cpe
echo "%{cpe}" > %{buildroot}/etc/system-release-cpe

# create /etc/issue and /etc/issue.net
echo '\S' > %{buildroot}/etc/issue
echo 'Kernel \r on an \m' >> %{buildroot}/etc/issue
cp %{buildroot}/etc/issue %{buildroot}/etc/issue.net
echo >> %{buildroot}/etc/issue

# copy GPG keys
mkdir -p -m 0755 %{buildroot}/etc/pki/rpm-gpg
for file in %{SOURCE20}; do
    install -m 0644 $file %{buildroot}/etc/pki/rpm-gpg
done

# copy yum repos
mkdir -p -m 0755 %{buildroot}/etc/yum.repos.d
for file in %{SOURCE10}; do
    install -m 0644 $file %{buildroot}/etc/yum.repos.d
done

# create default yum vars
mkdir -p -m 0755 %{buildroot}/etc/yum/vars
echo "amazonaws.com" > %{buildroot}/etc/yum/vars/awsdomain
echo "default" > %{buildroot}/etc/yum/vars/awsregion
echo "core" > %{buildroot}/etc/yum/vars/product

# install cloud-init configuration
mkdir -p -m 0755 %{buildroot}/etc/cloud/cloud.cfg.d
install -m 0644 %{SOURCE30} %{buildroot}/etc/cloud/cloud.cfg.d/

# set up the dist tag macros
install -d -m 0755 %{buildroot}/etc/rpm
cat >> %{buildroot}/etc/rpm/macros.dist << EOF
# dist macros.

%%amzn 2
%%centos_ver 7
%%centos 7
%%rhel 7
%%amzn2 1
%%el7 1
%%dist %dist
EOF

# use unbranded docdir
mkdir -p -m 0755 %{buildroot}/%{_docdir}/system-release
install -m 0644 %{SOURCE0} %{buildroot}/%{_docdir}/system-release/GPL

# copy systemd presets
mkdir -p %{buildroot}%{_presetdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_presetdir}/
install -m 0644 %{SOURCE2} %{buildroot}%{_presetdir}/

# Install MOTD scripts
install -d -m 755 %{buildroot}/etc/update-motd.d
install -m 755 %{SOURCE40} %{buildroot}/etc/update-motd.d/
install -m 755 %{SOURCE41} %{buildroot}/etc/update-motd.d/

%files
%defattr(0644,root,root,0755)
/etc/system-release
%config(noreplace) /etc/os-release
%config /etc/system-release-cpe
%config(noreplace) /etc/issue
%config(noreplace) /etc/issue.net
/etc/pki/rpm-gpg/
%config(noreplace) /etc/yum.repos.d/amzn2-core.repo
%config(noreplace) /etc/yum/vars/awsdomain
%config(noreplace) /etc/yum/vars/awsregion
%config(noreplace) /etc/yum/vars/product
%config(noreplace) /etc/cloud/cloud.cfg.d/10_aws_yumvars.cfg
/etc/rpm/macros.dist
%attr(0755,root,root) /etc/update-motd.d/30-banner
%attr(0755,root,root) /etc/update-motd.d/70-available-updates
%{_docdir}/system-release/GPL
%{_presetdir}/*


%changelog
